@@ -38,7 +38,7 @@ class Storage(driver.Base):
         if len(mpath) == 0:
             return
 
-        parts = mpath.split('/')[len(self.config.path.split('/')):]
+        parts = mpath.split('/')[len(self.config.path.split('/'))-1:]
         mpath = self.config.path
 
         for part in parts[3:]:
